pub fn set_logger<F>(callback: F)where
F: LoggerHandler,Expand description
Set a custom logging function to receive WebUI’s internal log messages. Useful for debugging or integrating with your own logging system.
pub fn set_logger<F>(callback: F)where
F: LoggerHandler,Set a custom logging function to receive WebUI’s internal log messages. Useful for debugging or integrating with your own logging system.