Javascript interop and related macros
Functions
- Get url page path with query data
- Get host from window
- Get origin from window
- Get url page path
- Get user data to store in appropriate container
- Generate a uuid from javasscript
- Check if given path matches the current browser path
- Log a message to the browser console.
- Handler for opening external links
- Push path to url
- General run method
- Set page transition duration
- Set the document/page title
- Set user data to store in appropriate container
- Run to flag user acceptance of persisting data across browser sessions
- Run to flag user acceptance of persisting data for the current tab/window session
- Run to flag user rejection of persisting browser data.