Event

Struct Event 

pub struct Event<'a> { /* private fields */ }
The event type.

Implementations

Source

impl<'a> Event<'a>

pub fn window(&self) -> Option<Window>

Get the window.

pub fn event_type(&self) -> EventType

Get the event type.

pub fn element(&self) -> String

Get the element.

pub fn event_number(&self) -> usize

Get the event number.

pub fn client_id(&self) -> usize

Get the client ID.

pub fn connection_id(&self) -> usize

Get the connection ID.

pub fn cookies(&self) -> Option<String>

Get the cookies.

pub fn show_client(&self, content: &str) -> Result<(), WebUIError>

Show a window for a specific single client. Useful in multi-client mode to send different content to different connected clients.

pub fn close_client(&self)

Close the connection for a specific single client only, without closing the window for other connected clients.

pub fn navigate_client(&self, url: &str)

Navigate a specific single client to a URL, without affecting other connected clients.

pub fn run_client(&self, script: &str)

Run JavaScript for a specific single client without waiting for a response.

pub fn script_client( &self, script: &str, timeout: usize, capacity: usize, ) -> Result<String, WebUIError>

Run JavaScript for a specific single client and get the response back.

pub fn get_count(&self) -> usize

Get the number of arguments passed to the callback from JavaScript.

pub fn get_int(&self) -> i64

Get the first argument as a 64-bit integer.

pub fn get_int_at(&self, index: usize) -> i64

Get an argument as a 64-bit integer at a specific index.

pub fn get_float(&self) -> f64

Get the first argument as a double-precision float.

pub fn get_float_at(&self, index: usize) -> f64

Get an argument as a double-precision float at a specific index.

pub fn get_string(&self) -> String

Get the first argument as a string slice.

pub fn get_string_at(&self, index: usize) -> String

Get an argument as a string slice at a specific index.

pub fn get_bool(&self) -> bool

Get the first argument as a boolean.

pub fn get_bool_at(&self, index: usize) -> bool

Get an argument as a boolean at a specific index.

pub fn get_size(&self) -> usize

Get the size in bytes of the first argument. Useful for raw binary data.

pub fn get_size_at(&self, index: usize) -> usize

Get the size in bytes of an argument at a specific index.

pub fn return_int(&self, value: i64)

Return a 64-bit integer as the response to a JavaScript await call.

pub fn return_float(&self, value: f64)

Return a double-precision float as the response to a JavaScript await call.

pub fn return_string<S: AsRef<str>>(&self, value: S)

Return a string as the response to a JavaScript await call.

pub fn return_bool(&self, value: bool)

Return a boolean as the response to a JavaScript await call.

pub fn send_raw<T>(&self, function: &str, data: T)
where T: Into<Vec<u8>>,

Send raw binary data to a JavaScript function for a specific single client only.