Struct webui::HookUpdater
source · [−]pub struct HookUpdater { /* private fields */ }Expand description
The HookUpdater provides a convenient interface for hooking into the lifecycle of
the underlying Yew Component that backs the function component.
Two interfaces are provided - callback and post_render.
callbackallows the creation of regular yew callbacks on the host component.post_renderallows the creation of events that happen after a render is complete.
See use_effect and use_context
for more details on how to use the hook updater to provide function components
the necessary callbacks to update the underlying state.
Implementations