wait_async

Function wait_async 

pub fn wait_async() -> bool
Non-blocking alternative to wait(). Returns true if at least one window is still open, false when all windows are closed. Call this in a loop from the main thread to interleave your own main-thread work.

Safety

In WebView mode, you must call this from the main thread.